NLSL: sscale.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
sscale.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | sscale (data, spct, wspct, ldspct, work, nsite, npt, ctol, noneg, iscal, sfac, resid)

## Function/Subroutine Documentation

subroutine sscale | ( | double precision, dimension(npt) | data,
|  | double precision, dimension(ldspct,nsite) | spct,
|  | double precision, dimension(ldspct,nsite) | wspct,
|  | integer | ldspct,
|  | double precision, dimension(npt) | work,
|  | integer | nsite,
|  | integer | npt,
|  | double precision | ctol,
|  | integer | noneg,
|  | integer, dimension(nsite) | iscal,
|  | double precision, dimension(nsite) | sfac,
|  | double precision, dimension(npt) | resid
| ) |  |

Definition at line 45 of file sscale.f90.

Here is the call graph for this function:

Here is the caller graph for this function: